@@ -187,11 +187,12 @@ union FFI_VAL **pvalues;     /* pointers to values */
 void
 frnfn_call (int type,double *pvalue,char **ppointer)  /* load and execute function from external library */
 {
-    char *call_err;
     int ffi_ret;
     union FFI_VAL ffi_result;
     void *fu;
-    int is_struct_not_string; /* distinguish return types */
+#ifdef UNIX
+    char *call_err;
+#endif
     
 
     last_frnfn_call_error_text[0] = '\0';
@@ -364,7 +365,7 @@ frnbf_set ()  /* set a value within a foreign buffer */
     int size;
     void *ptr;
     double val;
-    int offset;
+    size_t offset;
     char *type;
     ffi_type *valtype;
 
@@ -375,7 +376,7 @@ frnbf_set ()  /* set a value within a foreign buffer */
     if (!frn_decode_ffi_type(type, &valtype, NULL, ktSIMPLE)) return;
     if (!frnbf_verify_not_null(size)) return;
     if (offset<0 || ( size >= 0 && offset+valtype->size > size)) {
-	sprintf(estring, "overrun: offset of %d plus size of type %s = %lu exceeds size of buffer %d",
+	sprintf(estring, "overrun: offset of %ld plus size of type %s = %lu exceeds size of buffer %d",
 		offset, type, valtype->size, size);
 	error(sERROR, estring);
 	return;
@@ -417,7 +418,7 @@ frnbf_set_buffer ()  /* set a buffer within a foreign buffer */
 {
     int size1,size2;
     void *ptr1,*ptr2;
-    int offset;
+    size_t offset;
     ffi_type *bufftype;
 
     if (!frnbf_parse_handle(pop (stSTRING)->pointer, &size2, &ptr2)) return;
@@ -426,7 +427,7 @@ frnbf_set_buffer ()  /* set a buffer within a foreign buffer */
     frn_decode_ffi_type("buffer", &bufftype, NULL, ktCOMPLEX);
     if (!frnbf_verify_not_null(size1)) return;
     if (offset<0 || (size1 >= 0 && offset+bufftype->size > size1)) {
-	sprintf(estring, "overrun: offset of %d plus size of pointer = %lu exceeds size of buffer %d",
+	sprintf(estring, "overrun: offset of %ld plus size of pointer = %lu exceeds size of buffer %d",
 		offset, bufftype->size, size1);
 	error(sERROR, estring);
 	return;
@@ -443,7 +444,7 @@ frnbf_get ()  /* get a value from a foreign buffer */
 {
     int size;
     void *ptr;
-    int offset;
+    size_t offset;
     char *type;
     ffi_type *valtype;
 
@@ -453,7 +454,7 @@ frnbf_get ()  /* get a value from a foreign buffer */
     if (!frn_decode_ffi_type(type, &valtype, NULL, ktSIMPLE)) return 0.0;
     if (!frnbf_verify_not_null(size)) return 0.0;
     if (offset<0 || (size >= 0 && offset+valtype->size > size)) {
-	sprintf(estring, "overrun: offset of %d plus size of type %s = %lu exceeds size of buffer %d",
+	sprintf(estring, "overrun: offset of %ld plus size of type %s = %lu exceeds size of buffer %d",
 		offset, type, valtype->size, size);
 	error(sERROR, estring);
 	return 0.0;
