@@ -25,8 +25,11 @@
 #if defined(UNIX) && defined(WINDOWS)
 #error UNIX and WINDOWS are defined together; check your compiler settings
 #endif
+#ifdef WINDOWS
+#define _CRT_NONSTDC_NO_WARNINGS
+#endif
 /* ------------- includes ---------------- */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <float.h>
@@ -55,6 +58,7 @@
 #include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/ipc.h>
+#include <sys/ioctl.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Intrinsic.h>
@@ -84,6 +88,10 @@
 #ifndef LIBRARY_PATH
 #define LIBRARY_PATH "/usr/lib"
 #endif
+#ifdef HAVE_LINUX_PERF_EVENT_H
+#include <linux/perf_event.h>
+#include <linux/hw_breakpoint.h>
+#endif
 #endif
 #define OPEN_HAS_STREAM 1
 #define OPEN_HAS_MODE 2
